@@ -3,6 +3,7 @@
  * 
  *  xcdef.h - definitions for use throughout xclip
  *  Copyright (C) 2001 Kim Saunders
+ *  Copyright (C) 2007-2008 Peter Åstrand
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,10 +19,6 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* xclip version and name */
-#define XC_VERS 0.08
-#define XC_NAME "xclip"
-
 /* output level constants */
 #define OSILENT  0
 #define OQUIET   1
